@@ -13,6 +13,9 @@ from io import StringIO
 from math import floor
 from alacorder import run
 from alacorder import alac
+import warnings
+
+warnings.filterwarnings("ignore")
 
 print('''
 
@@ -23,7 +26,7 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 0.5.5
+		ALACORDER beta 0.5.7
 		by Sam Robson	
 
 
@@ -31,27 +34,29 @@ Welcome to Alacorder. Please select an operating mode:
 
 A.	EXPORTING DETAILED CASE INFORMATION AS A TABLE
 
-		Create detailed cases table with convictions, charges,
-		fees, and voting rights restoration information. 
+	Create detailed cases table with convictions, charges,
+	fees, and voting rights restoration information. 
 
 	Inputs:		PDF Directory (./path/to/pdfs) or 
-			Full Text Archive (.pkl, .csv, .xls, .json)
+			Archive (.pkl, .csv, .xls, .json)
 
-	Outputs:	Detailed Cases Table (.pkl, .csv, .xls, .dta, .json) 
-			or text file (.txt) if re-import is not needed
+	Outputs:	Detailed Cases Table 
+ 			(.pkl, .csv, .xls, .dta, .json) 
+			or non-importable text file (.txt)
 
 B.	CREATE A FULL TEXT ARCHIVE FROM PDF CASES
 
-		Search directory for PDF files, collect full text
-		and compress into archive. Archives can be processed
-		into tables with mode A or manually with alac.
+	Search directory for PDF files, collect full text
+	and compress into archive. Archives can be processed
+	into tables with mode A or manually with alac.
 
 	Inputs:		PDF Directory (./path/to/pdfs)
 
-	Outputs:	Full Text Archive (.pkl, .csv, .xls, .json) or
-			text file (.txt) if re-import is not needed
+	Outputs:	Archive (.pkl, .csv, .xls, .json) or
+			non-importable text file (.txt)
 
->> Enter A or B: ''')
+>> Enter A or B:
+''')
 
 ab = "".join(input()).strip()
 
@@ -62,14 +67,16 @@ if ab == "A":
 			ex.	/full/path/to/pdf/folder/
 			ex.	/full/path/to/fulltextarchive.pkl
 
-	>> Input path: ''')
+	>> Input path:
+''')
 elif ab == "B":
 	print(f'''
 
 	>>	Enter the input PDF directory path, including a forward-slash.
 			ex.	/full/path/to/pdf/folder/
 
-	>> Input path: ''')
+	>> Input path: 
+''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -86,7 +93,8 @@ if ab == "A":
 			ex.	/full/path/to/casestable.xls
 			ex.	/full/path/to/cases.csv
 
-	>> Output path: ''')
+	>> Output path: 
+''')
 elif ab == "B":
 	print(f'''
 
@@ -94,7 +102,8 @@ elif ab == "B":
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv
 
-	>> Output path: ''')
+	>> Output path: 
+''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -124,9 +133,12 @@ run.start(in_dir,xpath,mode,batch_size)
 
 if mode == "archive-from-directory":
 	print(f'''
->>		Would you like to create a detailed cases information table from the full text archive data?
+>>		Would you like to create a detailed cases 
+		information table from the 
+		full text archive data?
 
-Enter Y/N:	''')
+Enter Y/N:	
+''')
 	info = "".join(input()).strip()
 	if info == "Y":
 		print(f'''
@@ -134,10 +146,11 @@ Enter Y/N:	''')
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv 
 
-Output Path: ''')
+Output Path: 
+''')
 		in_dir = xpath
 		xpath = "".join(input()).strip()
-		run.start(in_dir,xpath,"tables-from-archive",batch_size=2000)
+		run.start(in_dir,xpath,"tables-from-archive",batch_size=2500)
 	if info == "N":
 		print(f'''
 			Alacorder completed the task and will now quit.
